.. _asdf_schemas:

Schemas
=======

Documentation for each of the individual ASDF schemas defined by ``astropy`` can
be found at the links below.

Documentation for the schemas defined in the ASDF Standard can be found `here
<https://asdf-standard.readthedocs.io/en/latest/schemas/index.html>`__.

.. contents::

Coordinates
-----------

The following schemas are associated with ``astropy`` types from the
:ref:`astropy-coordinates` submodule:

coordinates/angle-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/angle-1.0.0.yaml
   :language: yaml

coordinates/earthlocation-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/earthlocation-1.0.0.yaml
   :language: yaml

coordinates/latitude-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/latitude-1.0.0.yaml
   :language: yaml

coordinates/longitude-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/longitude-1.0.0.yaml
   :language: yaml

coordinates/representation-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/representation-1.0.0.yaml
   :language: yaml

coordinates/skycoord-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/coordinates/skycoord-1.0.0.yaml
   :language: yaml

FITS
----

The following schemas are associated with ``astropy`` types from the
:ref:`astropy-io-fits` submodule:

fits/fits-1.0.0
^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/fits/fits-1.0.0.yaml
   :language: yaml


Table
-----

The following schemas are associated with ``astropy`` types from the
:ref:`astropy-table` submodule:

table/table-1.0.0
^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/table/table-1.0.0.yaml
   :language: yaml


Time
----

The following schemas are associated with ``astropy`` types from the
:ref:`astropy-time` submodule:

time/timedelta-1.0.0
^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/time/timedelta-1.0.0.yaml
   :language: yaml


Units
-----

The following schemas are associated with ``astropy`` types from the
:ref:`astropy-units` submodule:

units/equivalency-1.0.0
^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../astropy/io/misc/asdf/data/schemas/astropy.org/astropy/units/equivalency-1.0.0.yaml
   :language: yaml
